##  RELATION_CREATED

```
{
  "id": 42846,
  "type": "RelationCreatedEvent",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "relation": {
    "id": "675aacdd-cfdf-4702-8084-0646e74533b9",
    "toId": "2efa37b5-18aa-48d8-9d70-1328c0d856d7",
    "type": "relToChild",
    "fields": [],
    "fromId": "95fbeddd-abdf-4552-a82b-ce37c287735c",
    "status": "ACTIVE",
    "naFields": [],
    "typeToFS": "Application",
    "typeFromFS": "Application",
    "displayNameToFS": "AC Management / AC Management Cloud",
    "permittedReadACL": [],
    "constrainingRelations": []
  },
  "createdAt": "2024-02-16T13:17:20.965779Z",
  "toDetails": {
    "factSheetInfos": {
      "type": "Application",
      "idAndRev": {
        "id": "2efa37b5-18aa-48d8-9d70-1328c0d856d7",
        "rev": 25
      },
      "displayName": "AC Management / AC Management Cloud"
    },
    "effectiveRelationName": "relToParent"
  },
  "relationId": "675aacdd-cfdf-4702-8084-0646e74533b9",
  "fromDetails": {
    "factSheetInfos": {
      "type": "Application",
      "idAndRev": {
        "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
        "rev": 3
      },
      "displayName": "AC Management"
    },
    "effectiveRelationName": "relToChild"
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "transactionSequenceNumber": 75089
}
```



